@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -67,7 +67,7 @@ NFacePairing::NFacePairing(const NTriangulation& tri) :
         for (f = 0; f < 4; f++) {
             adj = tet->getAdjacentTetrahedron(f);
             if (adj) {
-                pairs[index].tet = tri.getTetrahedronIndex(adj);
+                pairs[index].tet = tri.tetrahedronIndex(adj);
                 pairs[index].face = tet->getAdjacentFace(f);
             } else
                 pairs[index].setBoundary(nTetrahedra);
