@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -173,9 +173,16 @@ bool writeSnapPea(const char* filename, NTriangulation& tri) {
     int i, j;
     for (NTriangulation::TetrahedronIterator it = tri.getTetrahedra().begin();
             it != tri.getTetrahedra().end(); it++) {
+        // Although our precondition states that there are no boundary
+        // faces, we test for this anyway.  If somebody makes a mistake and
+        // calls this routine with a bounded triangulation, we don't want
+        // to wind up calling tetrahedronIndex(0) and crashing.
         for (i = 0; i < 4; i++)
-            out << "   " << tri.getTetrahedronIndex(
-                (*it)->getAdjacentTetrahedron(i)) << ' ';
+            if ((*it)->getAdjacentTetrahedron(i))
+                out << "   " << tri.tetrahedronIndex(
+                    (*it)->getAdjacentTetrahedron(i)) << ' ';
+            else
+                out << "   -1 ";
         out << '\n';
         for (i = 0; i < 4; i++)
             out << ' ' << (*it)->getAdjacentTetrahedronGluing(i).toString();
