@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -1188,6 +1188,64 @@ class NPacket : public ShareableObject {
          * will be inserted.
          */
         void internalCloneDescendants(NPacket* parent) const;
+
+        /**
+         * Calls NPacketListener::packetWasRenamed() for all registered
+         * packet listeners.
+         *
+         * Calling this routine is better than iterating through listeners
+         * manually, since it behaves correctly even if listeners unregister
+         * themselves as they handle the event.
+         */
+        void fireRenamedEvent();
+
+        /**
+         * Calls NPacketListener::packetToBeDestroyed() for all registered
+         * packet listeners.
+         *
+         * This routine unregisters each listener just before it calls
+         * packetToBeDestroyed() for that listener.
+         *
+         * Calling this routine is better than iterating through listeners
+         * manually, since it behaves correctly even if listeners unregister
+         * themselves or even destroy themselves and/or other listeners as
+         * they handle the event.
+         */
+        void fireDestructionEvent();
+
+        /**
+         * Calls NPacketListener::childWasAdded() for all registered
+         * packet listeners.
+         *
+         * Calling this routine is better than iterating through listeners
+         * manually, since it behaves correctly even if listeners unregister
+         * themselves as they handle the event.
+         *
+         * @param the child packet that was added beneath this packet.
+         */
+        void fireAddedEvent(NPacket* child);
+
+        /**
+         * Calls NPacketListener::childWasRemoved() for all registered
+         * packet listeners.
+         *
+         * Calling this routine is better than iterating through listeners
+         * manually, since it behaves correctly even if listeners unregister
+         * themselves as they handle the event.
+         *
+         * @param the child packet that was removed from beneath this packet.
+         */
+        void fireRemovedEvent(NPacket* child);
+
+        /**
+         * Calls NPacketListener::childrenWereReordered() for all registered
+         * packet listeners.
+         *
+         * Calling this routine is better than iterating through listeners
+         * manually, since it behaves correctly even if listeners unregister
+         * themselves as they handle the event.
+         */
+        void fireReorderedEvent();
 };
 
 /*@}*/
@@ -1223,23 +1281,6 @@ inline bool NPacket::hasTags() const {
     return (! tags->empty());
 }
 
-inline bool NPacket::addTag(const std::string& tag) {
-    if (! tags.get())
-        tags.reset(new std::set<std::string>());
-    return tags->insert(tag).second;
-}
-
-inline bool NPacket::removeTag(const std::string& tag) {
-    if (! tags.get())
-        return false;
-    return tags->erase(tag);
-}
-
-inline void NPacket::removeAllTags() {
-    if (tags.get())
-        tags->clear();
-}
-
 inline const std::set<std::string>& NPacket::getTags() const {
     if (! tags.get())
         const_cast<NPacket*>(this)->tags.reset(new std::set<std::string>());
