@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -62,8 +62,8 @@ NLayeredSolidTorus* NLayeredSolidTorus::clone() const {
 void NLayeredSolidTorus::transform(const NTriangulation* originalTri,
         const NIsomorphism* iso, NTriangulation* newTri) {
     unsigned i, j;
-    unsigned long baseTetID = originalTri->getTetrahedronIndex(base);
-    unsigned long topTetID = originalTri->getTetrahedronIndex(topLevel);
+    unsigned long baseTetID = originalTri->tetrahedronIndex(base);
+    unsigned long topTetID = originalTri->tetrahedronIndex(topLevel);
 
     // Data members nTetrahedra and meridinalCuts remain unchanged.
 
@@ -660,9 +660,9 @@ NTriangulation* NLayeredSolidTorus::flatten(const NTriangulation* original,
     NTriangulation* ans = new NTriangulation(*original);
 
     NTetrahedron* newTop = ans->getTetrahedron(
-        original->getTetrahedronIndex(topLevel));
+        original->tetrahedronIndex(topLevel));
     NTetrahedron* newBase = ans->getTetrahedron(
-        original->getTetrahedronIndex(base));
+        original->tetrahedronIndex(base));
 
     NPacket::ChangeEventBlock block(ans);
 
