@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -150,7 +150,7 @@ bool NTriangulation::crushMaximalForest() {
         cerr << "Dual Faces: " << dual.size() << '\n';
         NPointerSetIterator<NFace> it(dual);
         while (! it.done()) {
-            cerr << faces.index(*it) << ' ';
+            cerr << faceIndex(*it) << ' ';
             it++;
         }
         cerr << '\n';
@@ -160,7 +160,7 @@ bool NTriangulation::crushMaximalForest() {
     {
         NPointerSetIterator<NEdge> it(cEdges);
         while (! it.done()) {
-            cerr << edges.index(*it) << ' ';
+            cerr << edgeIndex(*it) << ' ';
             it++;
         }
         cerr << '\n';
@@ -281,7 +281,7 @@ bool NTriangulation::crushMaximalForest() {
     // For each tetrahedron, remove it and delete it.
     for (stdhash::hash_set<NTetrahedron*, HashPointer>::iterator tetIt =
             cTetrahedra.begin(); tetIt != cTetrahedra.end(); tetIt++) {
-        tetrahedra.erase(*tetIt);
+        tetrahedra.erase(tetrahedra.begin() + tetrahedronIndex(*tetIt));
         delete *tetIt;
     }
 
