@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -68,7 +68,7 @@ class NEdge;
  * changes, all its boundary component objects will be deleted and new
  * ones will be created.
  */
-class NBoundaryComponent : public ShareableObject {
+class NBoundaryComponent : public ShareableObject, public NMarkedElement {
     private:
         std::vector<NFace*> faces;
             /**< List of faces in the component. */
