@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -75,7 +75,7 @@ NTriangulation* NIsomorphism::apply(const NTriangulation* original) const {
         for (f = 0; f < 4; f++)
             if ((adjTet = myTet->getAdjacentTetrahedron(f))) {
                 // We have an adjacent tetrahedron.
-                adjTetIndex = original->getTetrahedronIndex(adjTet);
+                adjTetIndex = original->tetrahedronIndex(adjTet);
                 gluingPerm = myTet->getAdjacentTetrahedronGluing(f);
 
                 // Make the gluing from one side only.
