@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -37,6 +37,7 @@
 
 #include "shareableobject.h"
 #include "triangulation/nperm.h"
+#include "utilities/nmarkedvector.h"
 
 namespace regina {
 
@@ -66,7 +67,7 @@ class NComponent;
  * will ensure that skeletal information and other properties of the
  * triangulation are recalculated when necessary.
  */
-class NTetrahedron : public ShareableObject {
+class NTetrahedron : public ShareableObject, public NMarkedElement {
     private:
         NTetrahedron* tetrahedra[4];
             /**< Represents the tetrahedra glued to each face of this
