@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -37,6 +37,7 @@
 
 #include <vector>
 #include "shareableobject.h"
+#include "utilities/nmarkedvector.h"
 
 namespace regina {
 
@@ -118,7 +119,7 @@ class NVertexEmbedding {
  *
  * \testpart
  */
-class NVertex : public ShareableObject {
+class NVertex : public ShareableObject, public NMarkedElement {
     public:
         static const int SPHERE;
             /**< Specifies a vertex link that is a sphere. */
