@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -28,6 +28,7 @@
 
 #include <cstdarg>
 #include <iostream>
+#include <libxml/parserInternals.h>
 #include "utilities/xmlutils.h"
 
 #define ERROR_BUFF_SIZE 1024
@@ -77,7 +78,8 @@ xmlEntityPtr XMLParser::_get_entity(void*, const xmlChar* n) {
     return xmlGetPredefinedEntity(n);
 }
 void XMLParser::_start_document(void* parser) {
-    static_cast<XMLParser*>(parser)->_parser_callback.start_document();
+    static_cast<XMLParser*>(parser)->_parser_callback.start_document(
+        static_cast<XMLParser*>(parser));
 }
 void XMLParser::_end_document(void* parser) {
     static_cast<XMLParser*>(parser)->_parser_callback.end_document();
