@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -63,6 +63,8 @@ namespace xml {
  * @{
  */
 
+class XMLParser;
+
 /**
  * Represents a hashed map from property names to property values.
  *
@@ -112,8 +114,10 @@ class XMLParserCallback {
 
         /**
          * Called at the start of the document.
+         *
+         * @param parser the XML parser that is currently parsing this document.
          */
-        virtual void start_document();
+        virtual void start_document(XMLParser* parser);
         /**
          * Called when the document is finalised.
          */
@@ -363,7 +367,7 @@ inline const std::string& XMLPropertyDict::lookup(const std::string& key,
 
 inline XMLParserCallback::~XMLParserCallback() {
 }
-inline void XMLParserCallback::start_document() {
+inline void XMLParserCallback::start_document(XMLParser*) {
 }
 inline void XMLParserCallback::end_document() {
 }
