@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  KDE User Interface                                                    *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -27,6 +27,7 @@
 /* end stub */
 
 #include "regina-config.h"
+#include "file/nglobaldirs.h"
 #include "packet/npacket.h"
 
 // Put this before any Qt/KDE stuff so Python 2.3 "slots" doesn't clash.
@@ -41,7 +42,7 @@
 #include <iostream>
 #include <kaction.h>
 #include <kapplication.h>
-#include <kfiledialog.h>
+#include <kencodingfiledialog.h>
 #include <kglobalsettings.h>
 #include <khelpmenu.h>
 #include <klocale.h>
@@ -50,8 +51,11 @@
 #include <kpopupmenu.h>
 #include <kstatusbar.h>
 #include <ktextedit.h>
+#include <qfile.h>
 #include <qhbox.h>
 #include <qlabel.h>
+#include <qtextcodec.h>
+#include <qtextstream.h>
 #include <qvbox.h>
 #include <qwhatsthis.h>
 
@@ -224,7 +228,8 @@ bool PythonConsole::importRegina() {
             "The module should be installed as the file "
             "<tt>%1/regina.so</tt>.  Please write to %2 if you require "
             "further assistance.</qt>")
-            .arg(REGINA_PYLIBDIR).arg(PACKAGE_BUGREPORT));
+            .arg(QFile::decodeName(regina::NGlobalDirs::pythonModule().c_str()))
+            .arg(PACKAGE_BUGREPORT));
         addError(i18n("Unable to load module \"regina\"."));
         return false;
     }
@@ -283,7 +288,8 @@ void PythonConsole::loadAllLibraries() {
 
         QString shortName = QFileInfo((*it).filename).fileName();
         addOutput(i18n("Loading %1...").arg(shortName));
-        if (! interpreter->runScript((*it).filename, shortName)) {
+        if (! interpreter->runScript(
+                static_cast<const char*>(it->encodeFilename()), shortName)) {
             if (! QFileInfo((*it).filename).exists())
                 addError(i18n("The library %1 does not exist.").
                     arg((*it).filename));
@@ -318,14 +324,26 @@ void PythonConsole::executeScript(const QString& script,
 }
 
 void PythonConsole::saveLog() {
-    QString file = KFileDialog::getSaveFileName(QString::null,
+    KEncodingFileDialog::Result result =
+        KEncodingFileDialog::getSaveFileNameAndEncoding(
+        QString::null /* encoding */, QString::null,
         i18n(FILTER_ALL), this, i18n("Save Session Transcript"));
-    if (! file.isEmpty()) {
-        std::ofstream out(file.ascii());
-        if (! out)
+    if ((! result.fileNames.empty()) &&
+            (! result.fileNames.front().isEmpty())) {
+        QFile f(result.fileNames.front());
+        if (! f.open(IO_WriteOnly))
             KMessageBox::error(this, i18n("An error occurred whilst "
-                "attempting to write to the file %1.").arg(file));
+                "attempting to write to the file %1.").
+                arg(result.fileNames.front()));
         else {
+            QTextStream out(&f);
+
+            if (QTextCodec* encoding = QTextCodec::codecForName(
+                    result.encoding))
+                out.setCodec(encoding);
+            else
+                out.setEncoding(QTextStream::UnicodeUTF8);
+
             // Write the contents to file.
             // We can't just dump text() since this includes HTML tags.
             // We also can't just remove tags since tags and text that
@@ -335,7 +353,8 @@ void PythonConsole::saveLog() {
             // For the moment we'll do it through selections.  I'm sure
             // there's a better way.
             session->selectAll(true);
-            out << session->selectedText() << std::endl;
+            out << session->selectedText();
+            endl(out);
             session->selectAll(false);
         }
     }
