@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  KDE User Interface                                                    *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -26,6 +26,7 @@
 
 /* end stub */
 
+#include "file/nglobaldirs.h"
 #include "surfaces/nnormalsurfacelist.h"
 #include "utilities/stringutils.h"
 
@@ -35,10 +36,12 @@
 #include <fstream>
 #include <kstandarddirs.h>
 #include <qdir.h>
+#include <qfile.h>
 #include <qfileinfo.h>
+#include <qtextstream.h>
 
 namespace {
-    std::string INACTIVE("## INACTIVE ##");
+    QString INACTIVE("## INACTIVE ##");
 }
 
 const GraphvizStatus GraphvizStatus::unknown(0);
@@ -61,6 +64,10 @@ QString GraphvizStatus::cacheGraphvizExec;
 QString GraphvizStatus::cacheGraphvizExecFull;
 GraphvizStatus GraphvizStatus::cacheGraphvizStatus;
 
+QCString ReginaFilePref::encodeFilename() const {
+    return static_cast<const char*>(QFile::encodeName(filename));
+}
+
 GraphvizStatus GraphvizStatus::status(const QString& userExec,
         QString& fullExec, bool forceRecheck) {
     QMutexLocker lock(&cacheGraphvizMutex);
@@ -140,16 +147,12 @@ ReginaPrefSet::ReginaPrefSet() :
 ReginaFilePrefList ReginaPrefSet::defaultCensusFiles() {
     ReginaFilePrefList ans;
 
-    ans.push_back(ReginaFilePref(REGINA_DATADIR
-        "/examples/closed-or-census.rga"));
-    ans.push_back(ReginaFilePref(REGINA_DATADIR
-        "/examples/closed-nor-census.rga"));
-    ans.push_back(ReginaFilePref(REGINA_DATADIR
-        "/examples/knot-link-census.rga"));
-    ans.push_back(ReginaFilePref(REGINA_DATADIR
-        "/examples/snappea-census.rga"));
-    ans.push_back(ReginaFilePref(REGINA_DATADIR
-        "/examples/closed-hyp-census.rga"));
+    QString exDir = QFile::decodeName(regina::NGlobalDirs::examples().c_str());
+    ans.push_back(ReginaFilePref(exDir + "/closed-or-census.rga"));
+    ans.push_back(ReginaFilePref(exDir + "/closed-nor-census.rga"));
+    ans.push_back(ReginaFilePref(exDir + "/knot-link-census.rga"));
+    ans.push_back(ReginaFilePref(exDir + "/snappea-census.rga"));
+    ans.push_back(ReginaFilePref(exDir + "/closed-hyp-census.rga"));
 
     return ans;
 }
@@ -161,41 +164,44 @@ QString ReginaPrefSet::pythonLibrariesConfig() {
 bool ReginaPrefSet::readPythonLibraries() {
     pythonLibraries.clear();
 
-    std::ifstream in(pythonLibrariesConfig().ascii());
-    if (! in)
+    QFile f(pythonLibrariesConfig());
+    if (! f.open(IO_ReadOnly))
         return false;
 
-    bool active;
-    std::string line;
-    while (! in.eof()) {
-        line.clear();
-        std::getline(in, line);
+    QTextStream in(&f);
+    in.setEncoding(QTextStream::UnicodeUTF8);
 
+    bool active;
+    QString line = in.readLine();
+    while (! line.isNull()) {
         // Is the file inactive?
         active = true;
-        if (regina::startsWith(line, INACTIVE)) {
+        if (line.startsWith(INACTIVE)) {
             active = false;
-            line = line.substr(INACTIVE.length());
+            line = line.mid(INACTIVE.length());
         }
 
-        line = regina::stripWhitespace(line);
+        line = line.stripWhiteSpace();
 
-        // Is it a file at all?
-        if (line.empty() || line[0] == '#')
-            continue;
+        // Is it a file at all?  If so, add it.
+        if ((! line.isEmpty()) && line[0] != '#')
+            pythonLibraries.push_back(ReginaFilePref(line, active));
 
-        // Add the file.
-        pythonLibraries.push_back(ReginaFilePref(line.c_str(), active));
+        // Next!
+        line = in.readLine();
     }
 
     return true;
 }
 
 bool ReginaPrefSet::writePythonLibraries() const {
-    std::ofstream out(pythonLibrariesConfig().ascii());
-    if (! out)
+    QFile f(pythonLibrariesConfig());
+    if (! f.open(IO_WriteOnly))
         return false;
 
+    QTextStream out(&f);
+    out.setEncoding(QTextStream::UnicodeUTF8);
+
     out << "# Python libraries configuration file\n#\n";
     out << "# Automatically generated by the KDE user interface.\n\n";
 
