@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  KDE User Interface                                                    *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -35,6 +35,7 @@
 #define __PACKETIMPORTER_H
 
 class QString;
+class QTextCodec;
 class QWidget;
 
 namespace regina {
@@ -54,7 +55,8 @@ class PacketImporter {
         virtual ~PacketImporter();
 
         /**
-         * Import a packet tree from the given file.
+         * Import a packet tree from the given file.  The default UTF-8
+         * encoding should be assumed.
          *
          * If the import is unsuccessful, this routine should display
          * an appropriate error to the user (using the argument
@@ -66,9 +68,46 @@ class PacketImporter {
          */
         virtual regina::NPacket* import(const QString& fileName,
             QWidget* parentWidget) const = 0;
+
+        /**
+         * Import a packet tree from the given file using the given
+         * character encoding.
+         *
+         * This routine is identical to the simpler import() above, except
+         * that the encoding of the given file is explicitly specified
+         * (and might not be the default UTF-8).  If the given encoding
+         * is null, the routine should assume a default of UTF-8.
+         *
+         * The default implementation simply ignores the encoding and
+         * calls the simpler import() above.
+         */
+        virtual regina::NPacket* import(const QString& fileName,
+            QTextCodec* encoding, QWidget* parentWidget) const;
+
+        /**
+         * Should the GUI allow the user to choose a character encoding
+         * when selecting a file to import?
+         *
+         * If this routine returns \c true, the user will be offered a
+         * choice of encoding and the three-argument import() will be
+         * called.  Otherwise the user will not be offered a choice, and
+         * the two-argument import() will be called instead.
+         *
+         * The default implementation returns \c false.
+         */
+        virtual bool offerImportEncoding() const;
 };
 
 inline PacketImporter::~PacketImporter() {
 }
 
+inline regina::NPacket* PacketImporter::import(const QString& fileName,
+        QTextCodec*, QWidget* parentWidget) const {
+    return import(fileName, parentWidget);
+}
+
+inline bool PacketImporter::offerImportEncoding() const {
+    return false;
+}
+
 #endif
