@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  KDE User Interface                                                    *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -33,10 +33,12 @@
 
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <qfile.h>
 
 regina::NPacket* ReginaHandler::import(const QString& fileName,
         QWidget* parentWidget) const {
-    regina::NPacket* ans = regina::readFileMagic(fileName.ascii());
+    regina::NPacket* ans = regina::readFileMagic(
+        static_cast<const char*>(QFile::encodeName(fileName)));
     if (! ans)
         KMessageBox::error(parentWidget, i18n(
             "The file %1 could not be imported.  Perhaps it is not "
@@ -55,7 +57,7 @@ bool ReginaHandler::exportData(regina::NPacket* data,
             "This packet cannot be separated from its parent."));
         return false;
     }
-    if (! regina::writeXMLFile(fileName.ascii(), data, compressed)) {
+    if (! regina::writeXMLFile(QFile::encodeName(fileName), data, compressed)) {
         KMessageBox::error(parentWidget, i18n(
             "This packet subtree could not be exported.  An unknown error, "
             "probably related to file I/O, occurred during the export."));
