@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  KDE User Interface                                                    *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -373,9 +373,9 @@ void NTriCompositionUI::findAugTriSolidTori() {
             const regina::NTriSolidTorus& core = aug->getCore();
             details = new KListViewItem(id, details,
                 i18n("Core: tets %1, %2, %3").
-                arg(tri->getTetrahedronIndex(core.getTetrahedron(0))).
-                arg(tri->getTetrahedronIndex(core.getTetrahedron(1))).
-                arg(tri->getTetrahedronIndex(core.getTetrahedron(2))));
+                arg(tri->tetrahedronIndex(core.getTetrahedron(0))).
+                arg(tri->tetrahedronIndex(core.getTetrahedron(1))).
+                arg(tri->tetrahedronIndex(core.getTetrahedron(2))));
 
             if (aug->hasLayeredChain()) {
                 QString chainType;
@@ -460,11 +460,11 @@ void NTriCompositionUI::describeSatRegion(const NSatRegion& region,
             new KListViewItem(annuli,
                 i18n("%1 : Tet %2 (%3%4%5), Tet %6 (%7%8%9)").
                 arg(thisAnnulus).
-                arg(tri->getTetrahedronIndex(ann.tet[0])).
+                arg(tri->tetrahedronIndex(ann.tet[0])).
                 arg(ann.roles[0][0]).
                 arg(ann.roles[0][1]).
                 arg(ann.roles[0][2]).
-                arg(tri->getTetrahedronIndex(ann.tet[1])).
+                arg(tri->tetrahedronIndex(ann.tet[1])).
                 arg(ann.roles[1][0]).
                 arg(ann.roles[1][1]).
                 arg(ann.roles[1][2]));
@@ -608,7 +608,7 @@ void NTriCompositionUI::findL31Pillows() {
 
             details = new KListViewItem(id, details,
                 i18n("Pillow interior vertex: %1").
-                arg(tri->getVertexIndex(
+                arg(tri->vertexIndex(
                     pillow->getTetrahedron(0)->getVertex(
                     pillow->getInteriorVertex(0)))));
 
@@ -693,14 +693,14 @@ void NTriCompositionUI::findLayeredLoops() {
                     "Length %1, twisted").arg(loop->getLength()));
                 details = new KListViewItem(id, details, i18n(
                     "Hinge: edge %1").
-                    arg(tri->getEdgeIndex(loop->getHinge(0))));
+                    arg(tri->edgeIndex(loop->getHinge(0))));
             } else {
                 details = new KListViewItem(id, details, i18n(
                     "Length %1, not twisted").arg(loop->getLength()));
                 details = new KListViewItem(id, details, i18n(
                     "Hinges: edge %1, %2").
-                    arg(tri->getEdgeIndex(loop->getHinge(0))).
-                    arg(tri->getEdgeIndex(loop->getHinge(1))));
+                    arg(tri->edgeIndex(loop->getHinge(0))).
+                    arg(tri->edgeIndex(loop->getHinge(1))));
             }
 
             delete loop;
@@ -724,8 +724,8 @@ void NTriCompositionUI::findLayeredSolidTori() {
                 torus->getName().c_str());
 
             details = new KListViewItem(id, i18n("Base: tet %1").arg(
-                tri->getTetrahedronIndex(torus->getBase())));
-            topIndex = tri->getTetrahedronIndex(torus->getTopLevel());
+                tri->tetrahedronIndex(torus->getBase())));
+            topIndex = tri->tetrahedronIndex(torus->getTopLevel());
             details = new KListViewItem(id, details, i18n("Top level: tet %1").
                 arg(topIndex));
 
@@ -770,9 +770,9 @@ void NTriCompositionUI::findPillowSpheres() {
 
                 details = new KListViewItem(id, details, i18n(
                     "Equator: edges %1, %2, %3").
-                     arg(tri->getEdgeIndex(f1->getEdge(0))).
-                     arg(tri->getEdgeIndex(f1->getEdge(1))).
-                     arg(tri->getEdgeIndex(f1->getEdge(2))));
+                     arg(tri->edgeIndex(f1->getEdge(0))).
+                     arg(tri->edgeIndex(f1->getEdge(1))).
+                     arg(tri->edgeIndex(f1->getEdge(2))));
 
                 delete pillow;
             }
@@ -800,9 +800,9 @@ void NTriCompositionUI::findPlugTriSolidTori() {
             const regina::NTriSolidTorus& core(plug->getCore());
             details = new KListViewItem(id, details,
                 i18n("Core: tets %1, %2, %3").
-                arg(tri->getTetrahedronIndex(core.getTetrahedron(0))).
-                arg(tri->getTetrahedronIndex(core.getTetrahedron(1))).
-                arg(tri->getTetrahedronIndex(core.getTetrahedron(2))));
+                arg(tri->tetrahedronIndex(core.getTetrahedron(0))).
+                arg(tri->tetrahedronIndex(core.getTetrahedron(1))).
+                arg(tri->tetrahedronIndex(core.getTetrahedron(2))));
 
             QString lengths(i18n("Chain lengths: "));
             for (int j = 0; j < 3; j++) {
@@ -876,7 +876,7 @@ void NTriCompositionUI::findSnappedSpheres() {
 
                 const regina::NSnappedBall* ball = sphere->getSnappedBall(0);
                 details = new KListViewItem(id, details, i18n(
-                    "Equator: edge %1").arg(tri->getEdgeIndex(
+                    "Equator: edge %1").arg(tri->edgeIndex(
                     ball->getTetrahedron()->getEdge(ball->getEquatorEdge()))));
 
                 delete sphere;
@@ -917,8 +917,7 @@ void NTriCompositionUI::findSpiralSolidTori() {
 
             unsigned long* tetIndex = new unsigned long[spiralTets];
             for (j = 0; j < spiralTets; j++)
-                tetIndex[j] = tri->getTetrahedronIndex(
-                    spiral->getTetrahedron(j));
+                tetIndex[j] = tri->tetrahedronIndex(spiral->getTetrahedron(j));
 
             QString tetSet(spiralTets == 1 ? i18n("Tet: ") : i18n("Tets: "));
             for (j = 0; j < spiralTets; j++) {
