@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  KDE User Interface                                                    *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -398,7 +398,7 @@ void NTriGluingsUI::refresh() {
             adj = tet->getAdjacentTetrahedron(face);
             if (adj)
                 faceTable->setItem(tetNum, 4 - face, new FaceGluingItem(
-                    faceTable, editMode, face, tri->getTetrahedronIndex(adj),
+                    faceTable, editMode, face, tri->tetrahedronIndex(adj),
                     tet->getAdjacentTetrahedronGluing(face)));
             else
                 faceTable->setItem(tetNum, 4 - face,
@@ -807,7 +807,8 @@ void NTriGluingsUI::censusLookup() {
         progress->setLabel(i18n("Searching %1...").arg((*it).filename));
         KApplication::kApplication()->processEvents();
 
-        census = regina::readFileMagic((*it).filename.ascii());
+        census = regina::readFileMagic(
+            static_cast<const char*>(it->encodeFilename()));
         if (! census) {
             KMessageBox::error(ui, i18n("The census data file %1 "
                 "could not be read.\nYou might consider temporarily "
