@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  KDE User Interface                                                    *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -29,6 +29,7 @@
 #include "regina-config.h"
 
 #include "file/nfileinfo.h"
+#include "file/nglobaldirs.h"
 
 #include "coordinatechooser.h"
 #include "reginafilter.h"
@@ -48,6 +49,7 @@
 #include <ktexteditor/editorchooser.h>
 #include <ktip.h>
 #include <qcheckbox.h>
+#include <qfile.h>
 #include <qheader.h>
 #include <qlabel.h>
 #include <qlayout.h>
@@ -810,8 +812,8 @@ void ReginaPrefCensus::add() {
                 it != files.end(); it++) {
             // Run a basic check over the file.
             bool active = true;
-            regina::NFileInfo* info =
-                regina::NFileInfo::identify((*it).ascii());
+            regina::NFileInfo* info = regina::NFileInfo::identify(
+                static_cast<const char*>(QFile::encodeName(*it)));
             if (! info) {
                 if (KMessageBox::warningContinueCancel(this,
                         i18n("The file %1 does not appear "
@@ -1022,7 +1024,8 @@ void ReginaPrefPython::updateButtons() {
 }
 
 void ReginaPrefPython::add() {
-    QStringList files = KFileDialog::getOpenFileNames(QString::null,
+    QStringList files = KFileDialog::getOpenFileNames(
+        QFile::decodeName(regina::NGlobalDirs::pythonLibs().c_str()),
         FILTER_PYTHON_LIBRARIES, this, i18n("Add Python Libraries"));
     if (! files.isEmpty()) {
         for (QStringList::const_iterator it = files.begin();
