@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Python Interface                                                      *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -27,10 +27,12 @@
 /* end stub */
 
 void addNFileInfo();
+void addNGlobalDirs();
 void addNXMLFile();
 
 void addFile() {
     addNFileInfo();
+    addNGlobalDirs();
     addNXMLFile();
 }
 
