@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Python Interface                                                      *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -26,6 +26,7 @@
 
 /* end stub */
 
+void addLocale();
 void addNBoolSet();
 void addNLargeInteger();
 void addNMatrix2();
@@ -33,6 +34,7 @@ void addNRational();
 void addNTriBool();
 
 void addUtilities() {
+    addLocale();
     addNBoolSet();
     addNLargeInteger();
     addNMatrix2();
