@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Test Suite                                                            *
  *                                                                        *
- *  Copyright (c) 1999-2007, Ben Burton                                   *
+ *  Copyright (c) 1999-2008, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -75,6 +75,11 @@ class NSnapPeaTriangulationTest : public CppUnit::TestFixture {
          */
         NTriangulation closedHypOr, closedHypNor;
 
+        /**
+         * The Seifert-Weber dodecahedral space:
+         */
+        NTriangulation seifertWeber;
+
         /**
          * Triangulations of 3-manifolds whose reported volume should be zero.
          *
@@ -139,6 +144,9 @@ class NSnapPeaTriangulationTest : public CppUnit::TestFixture {
             copyAndDelete(closedHypNor,
                 NExampleTriangulation::smallClosedNonOrblHyperbolic());
 
+            copyAndDelete(seifertWeber,
+                NExampleTriangulation::seifertWeber());
+
             t = new NTetrahedron();
             s = new NTetrahedron();
             t->joinTo(0, s, NPerm(0,1,2,3));
@@ -326,6 +334,19 @@ class NSnapPeaTriangulationTest : public CppUnit::TestFixture {
                 "A closed non-orientable hyperbolic triangulation "
                 "should not be representable in SnapPea format.");
 
+            CPPUNIT_ASSERT_MESSAGE(
+                "The Seifert-Weber dodecahedral space "
+                "appears to have been incorrectly constructed.",
+                seifertWeber.isValid() &&
+                seifertWeber.isConnected() &&
+                seifertWeber.isOrientable() &&
+                (! seifertWeber.isIdeal()) &&
+                seifertWeber.isStandard() &&
+                (! seifertWeber.hasBoundaryFaces()));
+            testIncompatible(seifertWeber,
+                "The Seifert-Weber dodecahedral space is closed, and so "
+                "should not be representable in SnapPea format.");
+
             CPPUNIT_ASSERT_MESSAGE(
                 "The cusped solid torus with finite vertex "
                 "appears to have been incorrectly constructed.",
@@ -403,6 +424,7 @@ class NSnapPeaTriangulationTest : public CppUnit::TestFixture {
 
             // testVolume(closedHypOr, "or_0.94270736", 0.94270736, 7);
             // testVolume(closedHypNor, "nor_2.02988321", 2.02988121, 7);
+            // testVolume(seifertWeber, "Seifert Weber", 11.1990647, 6);
         }
 
         void testZeroVolume(const char* triName, double foundVol,
